@@ -1,22 +1,18 @@
 """Contains utility functions used in the library."""
 
 __author__ = "Ederson Corbari"
-__email__ = "e@neural7.io"
-__copyright__ = "Copyright Neural7 2022, Big 5 Personality Traits"
+__email__ = "e@rewire5.io"
+__copyright__ = "Copyright ReWire5 2022-2023, Big 5 Personality Traits"
 __credits__ = ["John A. Johnson", "Dhiru Kholia"]
 __license__ = "MIT"
-__version__ = "1.8.0"
+__version__ = "1.9.0"
 __status__ = "production"
 
+from datetime import datetime
 from enum import Enum
 
-from ipipneo.model import (
-    Big5Agreeableness,
-    Big5Conscientiousness,
-    Big5Extraversion,
-    Big5Neuroticism,
-    Big5Openness,
-)
+from ipipneo.model import (Big5Agreeableness, Big5Conscientiousness,
+                           Big5Extraversion, Big5Neuroticism, Big5Openness)
 
 
 def raise_if_sex_is_invalid(sex: str) -> bool or AssertionError or BaseException:
@@ -48,7 +44,9 @@ def raise_if_age_is_invalid(age: int) -> bool or AssertionError or BaseException
 
     min, max = (10, 110)
     if not (min <= age <= max):
-        raise AssertionError("The age (%r) must be between %r and %r!" % (age, min, max))
+        raise AssertionError(
+            "The age (%r) must be between %r and %r!" % (age, min, max)
+        )
 
     return True
 
@@ -71,7 +69,9 @@ def answers_is_valid(answers: list) -> bool or AssertionError or BaseException:
     if 1 in [1 if x > 5 else 0 for x in answers]:
         raise BaseException("You cannot have answers with a number greater than 5!")
 
-    assert len(answers) == 120 or len(answers) == 300, "The (answers) field should be of size 120 or 300!"
+    assert (
+        len(answers) == 120 or len(answers) == 300
+    ), "The (answers) field should be of size 120 or 300!"
 
     return True
 
@@ -96,7 +96,9 @@ def organize_list_json(answers: dict) -> list or AssertionError or BaseException
 
     return [
         x["id_select"]
-        for x in sorted([x for x in answers.get("answers", [])], key=lambda x: x["id_question"])
+        for x in sorted(
+            [x for x in answers.get("answers", [])], key=lambda x: x["id_question"]
+        )
         if x["id_select"] >= 1
     ]
 
@@ -148,7 +150,9 @@ def big5_target(label: str) -> Enum or BaseException:
     Args:
         - label: The acronym for the Big-Five standard O.C.E.A.N.
     """
-    if big5_ocean_is_valid(label=label):
+    big5_ocean_is_valid(label=label)
+
+    try:
         if label == "O":
             return Big5Openness
         if label == "C":
@@ -159,6 +163,8 @@ def big5_target(label: str) -> Enum or BaseException:
             return Big5Agreeableness
         if label == "N":
             return Big5Neuroticism
+    except BaseException:
+        raise BaseException("The Big-Five label is invalid!")
 
 
 def create_big5_dict(label: str, big5: float, x: list, y: list) -> dict:
@@ -206,3 +212,11 @@ def create_big5_dict(label: str, big5: float, x: list, y: list) -> dict:
             },
         ],
     }
+
+
+def add_dict_footer() -> dict:
+    return {
+        "library": "five-factor-e",
+        "version": __version__,
+        "date": datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
+    }
